@@ -7,6 +7,11 @@
 DOMAIN_NAME = ''
 
 
+# ## Default Serializing scheme
+# serialize data and bind it with type names
+WITH_TYPE_NAME = False
+
+
 # ## Default Date and time Format
 # using UTC Format, see http://www.w3.org/TR/NOTE-datetime for details
 DATE_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
@@ -17,10 +22,10 @@ PER_PAGE = 20
 
 
 # ## Default Authorizer Class
-AUTH = 'resource.BasicAuth'
+AUTH = 'rsrc.BasicAuth'
 
 
 # ## Default settings for token
 SECRET_KEY = 'your-own-secret-key'
 TOKEN_EXPIRES = 3600
-TOKEN_USER = 'resource.contrib.token.TokenUser'
+TOKEN_USER = 'rsrc.contrib.token.TokenUser'
